@@ -2,12 +2,14 @@ convert_mbox_eml <- function(mbox, dir) {
     dir.create(dir, recursive = TRUE)
     content <- readLines(mbox)
     counter <- start <- end <- 1
+    nMessages <- length(grep("^From ", content, useBytes = TRUE))
+    fmt <- paste("%0", nchar(nMessages), "d", sep = "")
     needWrite <- FALSE
     for (i in seq_along(content)) {
-        if (length(grep("^From ", content[i])) > 0) {
+        if (length(grep("^From ", content[i], useBytes = TRUE)) > 0) {
             end <- i - 1
             if (needWrite && start <= end) {
-                con <- file(file.path(dir, counter))
+                con <- file(file.path(dir, sprintf(fmt, counter)))
                 writeLines(content[start:end], con)
                 close(con)
                 needWrite <- FALSE
@@ -17,14 +19,18 @@ convert_mbox_eml <- function(mbox, dir) {
             needWrite <- TRUE
         }
     }
-    if (needWrite)
-        writeLines(content[start:length(content)], file(file.path(dir, counter)))
+    if (needWrite) {
+        con <- file(file.path(dir, sprintf(fmt, counter)))
+        writeLines(content[start:length(content)], con)
+        close(con)
+    }
+    invisible(TRUE)
 }
 
 # Remove e-mail citations beginning with >
 removeCitation <- function(x) UseMethod("removeCitation", x)
 removeCitation.character <- function(x) {
-    citations <- grep("^[[:blank:]]*>", x)
+    citations <- grep("^[[:blank:]]*>", x, useBytes = TRUE)
     if (length(citations)) x[-citations] else x
 }
 removeCitation.MailDocument <- function(x) {
@@ -38,7 +44,7 @@ removeMultipart <- function(x) UseMethod("removeMultipart", x)
 removeMultipart.character <- function(x) {
     # http://en.wikipedia.org/wiki/Multipart_message#Multipart_Messages
     # We are only interested in text/plain parts
-    i <- grep("^Content-Type: text/plain", x)
+    i <- grep("^Content-Type: text/plain", x, useBytes = TRUE)
     r <- character(0)
     k <- 2
     for (j in i) {
@@ -55,13 +61,13 @@ removeMultipart.character <- function(x) {
             else
                 j <- j - 1
         }
-        index <- grep(x[start], content)
+        index <- grep(x[start], content, useBytes = TRUE)
         index <- if (length(index) == 0) length(content) else (index[1] - 1)
         content <- content[1:index]
         # Now remove remaining headers
-        index <- grep("^$", content)
+        index <- grep("^$", content, useBytes = TRUE)
         index <- if (length(index) == 0) 1 else (index[1] + 1)
-        r <- x(r, content[index:length(content)])
+        r <- c(r, content[index:length(content)])
         k <- k + 1
     }
 
@@ -85,7 +91,7 @@ removeSignature.character <- function(x, marks = character(0)) {
 
     signatureStart <- length(x) + 1
     for (m in marks)
-        signatureStart <- min(grep(m, x), signatureStart)
+        signatureStart <- min(grep(m, x, useBytes = TRUE), signatureStart)
 
     if (signatureStart <= length(x)) x[-(signatureStart:length(x))]
     else x
@@ -104,7 +110,7 @@ threads <- function(x) {
     threadIDs <- threadLevels <- integer(length(x))
     for (i in seq_along(x)) {
         messageID <- tm::ID(x[[i]])
-        parentID <- gsub("In-Reply-To: ", "", grep("^In-Reply-To:", attr(x[[i]], "Header"), value = TRUE))
+        parentID <- gsub("In-Reply-To: ", "", grep("^In-Reply-To:", attr(x[[i]], "Header"), value = TRUE, useBytes = TRUE))
         # Generate new thread
         if (!length(parentID)) {
             ht[[messageID]] <- c(tid, 1)
